﻿using Common.Types.Middleware.Currencies;
using Connected.Interop;
using Connected.Middleware;
using System.Globalization;

namespace Common.Types.Currencies;

internal class DefaultCurrencyFormatterMiddleware<TValue> : MiddlewareComponent, ICurrencyFormatterMiddleware<TValue>
{
	public Task<string?> Format(TValue value, ICurrency currency, string format)
	{
		if (value is null)
			return Task.FromResult<string?>(null);

		if (string.IsNullOrWhiteSpace(format))
			format = "N2";

		var culture = currency.Lcid == 0 ? CultureInfo.CurrentUICulture : CultureInfo.GetCultureInfo(currency.Lcid);

		if (!TypeConversion.TryConvert(value, out double converted, culture))
			return Task.FromResult(value.ToString());

		return Task.FromResult<string?>(converted.ToString(format, culture));
	}
}
